@@ -49,11 +49,17 @@ async def list(args):
     _t = Table('ID', 'Status', 'Gateway', box=box.ROUNDED, highlight=True)
 
     console = Console()
-    with console.status(f'[bold]Listing all flows...'):
-        _result = await CloudFlow().list_all()
-        for k in _result:
-            _t.add_row(k['id'].split('-')[-1], k['status'], k['gateway'])
-        console.print(_t)
+    _status = args.status
+    with console.status(
+        f'[bold]Listing flows with status [green]{_status}[/green] ...'
+        if _status is not None or _status != 'ALL'
+        else '[bold] Listing all Flows'
+    ):
+        _result = await CloudFlow().list_all(status=args.status)
+        if _result:
+            for k in _result:
+                _t.add_row(k['id'].split('-')[-1], k['status'], k['gateway'])
+            console.print(_t)
 
 
 @asyncify
@@ -63,7 +69,22 @@ async def remove(args):
 
 @asyncify
 async def logs(args):
-    await CloudFlow.logstream(params={'flow_id': args.flow})
+    from rich.console import Console
+
+    from .flow import pb_task, pbar
+
+    with pbar:
+        pbar.start_task(pb_task)
+        pbar.update(
+            pb_task,
+            total=1,
+            description=f'Press Ctrl-C to quit',
+            title=f'Live streaming from {args.flow}',
+        )
+        _params = {'flow_id': args.flow}
+        if args.executor is not None:
+            _params['executor'] = args.executor
+        await CloudFlow.logstream(_params)
 
 
 @asyncify
@@ -74,7 +95,9 @@ async def login(args):
 
 
 def new(args):
-    import shutil, os, sys
+    import os
+    import shutil
+    import sys
 
     rp = os.path.join(os.path.dirname(sys.modules['jcloud'].__file__), 'resources')
 
@@ -85,3 +108,10 @@ def new(args):
     print(
         f'[green]New project create under {args.path}[/green]. Try [b]jc deploy {args.path}[/b].'
     )
+
+
+def survey(args):
+    # ask feedback
+    from .auth import Survey
+
+    Survey().ask(-1)
